summaryrefslogtreecommitdiff
path: root/src/xfpm-xfconf.c
diff options
context:
space:
mode:
authorSimon Steinbeiss <simon.steinbeiss@elfenbeinturm.at>2014-06-23 15:37:51 +0200
committerEric Koegel <eric.koegel@gmail.com>2014-06-26 19:49:52 +0300
commit7dd51ceaa91ecba72154dd15ecca6ddd7f33b120 (patch)
treef1f0749f6879462bf70494f0d08441f063484f94 /src/xfpm-xfconf.c
parent638f47159a248aed8aa9df39aee40d1810646a7a (diff)
downloadixfce4-power-manager-7dd51ceaa91ecba72154dd15ecca6ddd7f33b120.tar.gz
Let xfpm control X11's screensaver extension FIXME: dbus_init in power.c resets the configured values if xfpm restarts
Diffstat (limited to 'src/xfpm-xfconf.c')
-rw-r--r--src/xfpm-xfconf.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/xfpm-xfconf.c b/src/xfpm-xfconf.c
index d3015380..848b6a08 100644
--- a/src/xfpm-xfconf.c
+++ b/src/xfpm-xfconf.c
@@ -191,8 +191,10 @@ xfpm_xfconf_property_changed_cb (XfconfChannel *channel, gchar *property,
if ( !g_str_has_prefix (property, PROPERTIES_PREFIX) || strlen (property) <= strlen (PROPERTIES_PREFIX) )
return;
- /* We handle presentation mode in xfpm-power directly */
- if ( g_strcmp0 (property, "/xfce4-power-manager/presentation-mode") == 0 )
+ /* We handle presentation mode and blank-times in xfpm-power directly */
+ if ( g_strcmp0 (property, "/xfce4-power-manager/presentation-mode") == 0 ||
+ g_strcmp0 (property, "/xfce4-power-manager/blank-on-ac") == 0 ||
+ g_strcmp0 (property, "/xfce4-power-manager/blank-on-battery") == 0)
return;
XFPM_DEBUG ("Property modified: %s\n", property);